@@ -42,6 +42,7 @@ class TalosClientConfig:
     _maxBufferedMsgTime = int
     _maxPutMsgNumber = int
     _maxPutMsgBytes = int
+    _maxSingleMessageBytes = int
     _producerCheckPartitionInterval = int
     # put failed related private
     _maxRetryTimes = int
@@ -246,6 +247,9 @@ class TalosClientConfig:
         self._putMessageMaxFailedTimes = pro.get(
             TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_PUT_MESSAGE_MAX_FAILED_TIMES,
             TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_PUT_MESSAGE_MAX_FAILED_TIMES_DEFAULT)
+        self._maxSingleMessageBytes = pro.get(
+            TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_MAX_SINGLE_MESSAGE_BYTES,
+            TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_MAX_SINGLE_MESSAGE_BYTES_DEFAULT)
 
     def get_max_retry(self):
         return self._maxRetry
@@ -317,6 +321,9 @@ class TalosClientConfig:
     def get_max_put_msg_bytes(self):
         return self._maxPutMsgBytes
 
+    def get_max_single_msg_bytes(self):
+        return self._maxSingleMessageBytes
+
     def get_thread_pool_size(self):
         return self._threadPoolSize
 
