@@ -125,7 +125,11 @@ class SimpleConsumer:
             return messageAndOffsetList
         else:
             start = int(startOffset - actualStartOffset)
-            assert start > 0
+            try:
+                assert start > 0
+            except AssertionError as e:
+                self.logger.error("Exception in fetch_message: %", e)
+                raise e
             end = len(messageAndOffsetList)
             return messageAndOffsetList[start:end]
 
