@@ -239,7 +239,10 @@ class TalosConsumer(object):
     # 'CheckWorkerInfoTask' takes charge of updating workerInfoMap
     #
     def re_balance_task(self):
-        self.make_balance()
+        try:
+            self.make_balance()
+        except Exception as e:
+            logger.error("Exception in make_balance" + str(traceback.format_exc()))
 
     #
     # ReNew Task(contains two sections per renew)
@@ -400,7 +403,10 @@ class TalosConsumer(object):
                 targetList.append(min)
                 sum += min
                 index += 1
-            assert sum == copyPartitionNum
+            try:
+                assert sum == copyPartitionNum
+            except AssertionError as error:
+                raise error
 
         # sort target by descending
         targetList.sort(reverse=True)
@@ -477,7 +483,11 @@ class TalosConsumer(object):
             i += 1
 
         # steal or release partition lock or reached a balance state
-        assert not (len(toStealList) > 0 and len(toReleaseList) > 0)
+        try:
+            assert not (len(toStealList) > 0 and len(toReleaseList) > 0)
+        except AssertionError as error:
+            raise error
+
         if len(toStealList) > 0:
             self.steal_partition_lock(toStealList)
         elif len(toReleaseList) > 0:
@@ -517,7 +527,11 @@ class TalosConsumer(object):
                     + " partition: " + str(toReleaseList))
         # stop read, commit offset, unlock the partition async
         for partitionId in toReleaseList:
-            assert partitionId in self.partitionFetcherMap
+            try:
+                assert partitionId in self.partitionFetcherMap
+            except AssertionError as error:
+                logger.warning("Worker: %s try to release partition: %d failed: %s", self.workerId, partitionId, error)
+                continue
             self.partitionFetcherMap.get(partitionId).unlock()
             del self.partitionFetcherMap[partitionId]
 
@@ -532,16 +546,20 @@ class TalosConsumer(object):
 
     def get_idle_partitions(self):
         self.readWriteLock.read_acquire()
-        assert self.partitionNumber > 0
-        idlePartitions = []
-        i = 0
-        while i < self.partitionNumber:
-            idlePartitions.append(i)
-            i += 1
-        for valueList in self.workerInfoMap.values():
-            for partitionId in valueList:
-                idlePartitions.remove(partitionId)
-        self.readWriteLock.read_release()
+        try:
+            assert self.partitionNumber > 0
+            idlePartitions = []
+            i = 0
+            while i < self.partitionNumber:
+                idlePartitions.append(i)
+                i += 1
+            for valueList in self.workerInfoMap.values():
+                for partitionId in valueList:
+                    idlePartitions.remove(partitionId)
+        except Exception as error:
+            raise error
+        finally:
+            self.readWriteLock.read_release()
         return idlePartitions
 
     def shut_down_fetcher(self):
