@@ -62,7 +62,7 @@ class PartitionMessageQueue:
                         self.logger.error(e.errMsg)
                     self.logger.error("getUserMessageList for partition: " +
                                       str(self.partitionId) + " is interrupt when waiting: "
-                                      + traceback.format_exc())
+                                      + str(traceback.format_exc()))
 
         if self.logger.isEnabledFor(level=logging.DEBUG):
             self.logger.debug("getUserMessageList wake up for partition: "
@@ -88,7 +88,8 @@ class PartitionMessageQueue:
             self.logger.debug("Ready to put message batch: " + str(len(returnList)) +
                               " queue size: " + str(len(self.userMessageList))
                               + " and curBytes: " + str(self.curMessageBytes) +
-                              " for partition: " + str(len(self.partitionId)))
+                              " for partition: " + str(self.partitionId))
+        self.globalLock.release()
         return returnList
 
     @synchronized
@@ -107,7 +108,6 @@ class PartitionMessageQueue:
             curBufferedTime = Utils.current_time_mills() - self.userMessageList[len(self.userMessageList) - 1].get_timestamp()
             if curBufferedTime >= self.maxBufferedTime:
                 return True
-
         return False
 
     #
@@ -117,7 +117,7 @@ class PartitionMessageQueue:
     @synchronized
     def get_wait_time(self):
         if len(self.userMessageList) <= 0:
-            return 0
+            return 3600
         time = (self.userMessageList[len(self.userMessageList) - 1].get_timestamp()
                 + self.maxBufferedTime - Utils.current_time_mills()) / 1000
         if time > 0:
