@@ -78,7 +78,7 @@ class SimpleProducer(object):
             self.put_message_list(msgList)
             return True
         except Exception as e:
-            self.logger.error("putMessage error， please try to put again", e)
+            self.logger.error("putMessage to " + self.topicAndPartition + " error， please try to put again", e)
 
         return False
 
@@ -118,11 +118,11 @@ class SimpleProducer(object):
                     putMessageResponse = self.messageClient.put_message(putMessageRequest)
                 else:
                     self.logger.error(
-                        "put message request failed." + str(traceback.format_exc()))
+                        "put message request to " + self.topicAndPartition + " failed." + str(traceback.format_exc()))
                     raise e
             else:
                 self.logger.error(
-                    "put message request failed." + str(traceback.format_exc()))
+                    "put message request to " + self.topicAndPartition + " failed." + str(traceback.format_exc()))
                 raise e
 
         # update scheduleInfocache when request have been transfered and talos auto location was set up
