@@ -154,82 +154,90 @@ class TalosProducer(object):
 
     @synchronized
     def add_user_message(self, msgList=None, partitionId=None):
-        if not self.is_active():
-            raise ProducerNotActiveException("Producer is not active, current state: "
-                                             + str(self.producerState))
+        try:
+            if not self.is_active():
+                raise ProducerNotActiveException("Producer is not active, current state: "
+                                                 + str(self.producerState))
 
-        # check total buffered message number
-        while self.bufferedCount.is_full():
-            with self.lock:
-                try:
-                    self.logger.info("too many buffered messages, globalLock is active."
-                                     + " message number: " +
-                                     str(self.bufferedCount.get_buffered_msg_number())
-                                     + ", message bytes:  " +
-                                     str(self.bufferedCount.get_buffered_msg_bytes()))
-                    # release global lock but no notify
-                    self.globalLock.acquire()
-                    self.globalLock.wait()
-                    self.globalLock.release()
-                except Exception as e:
-                    self.logger.error("addUserMessage global lock wait is interrupt."
-                                      + e.message)
+            # check total buffered message number
+            while self.bufferedCount.is_full():
+                with self.lock:
+                    try:
+                        self.logger.info("too many buffered messages, globalLock is active."
+                                         + " message number: " +
+                                         str(self.bufferedCount.get_buffered_msg_number())
+                                         + ", message bytes:  " +
+                                         str(self.bufferedCount.get_buffered_msg_bytes()))
+                        # release global lock but no notify
+                        self.globalLock.acquire()
+                        self.globalLock.wait()
+                        self.globalLock.release()
+                    except Exception as e:
+                        self.logger.error("addUserMessage global lock wait is interrupt."
+                                          + e.message)
 
-        if partitionId is None:
-            self.do_add_user_message(msgList)
-        else:
-            userMessageList = []
+            if partitionId is None:
+                self.do_add_user_message(msgList)
+            else:
+                userMessageList = []
 
-            for message in msgList:
-                # set timestamp and messageType if not set
-                Utils.update_message(message, MessageType.BINARY)
-                # check data validity
-                Utils.check_message_validity(message, self.talosProducerConfig)
-                userMessageList.append(UserMessage(message))
+                for message in msgList:
+                    # set timestamp and messageType if not set
+                    Utils.update_message(message, MessageType.BINARY)
+                    # check data validity
+                    Utils.check_message_validity(message, self.talosProducerConfig)
+                    userMessageList.append(UserMessage(message))
 
-            assert partitionId in self.partitionSenderMap
-            self.partitionSenderMap.get(partitionId).add_message(userMessageList)
+                assert partitionId in self.partitionSenderMap
+                self.partitionSenderMap.get(partitionId).add_message(userMessageList)
+        except Exception as e:
+            self.logger.error("add_user_message func error: " + traceback.format_exc())
+            raise e
 
     # @synchronized
     def do_add_user_message(self, msgList=None):
-        # user can optionally set 'partitionKey' and 'sequenceNumber' when construct Message
-        partitionBufferMap = dict()
+        try:
+            # user can optionally set 'partitionKey' and 'sequenceNumber' when construct Message
+            partitionBufferMap = dict()
 
-        # check / update curPartitionId
-        if self.should_update_partition():
-            self.curPartitionId = (self.curPartitionId + 1) % self.partitionNumber
-            self.lastUpdatePartitionIdTime = Utils.current_time_mills()
-            self.lastAddMsgNumber = 0
-        currentPartitionId = self.curPartitionId
-        self.lastAddMsgNumber += len(msgList)
+            # check / update curPartitionId
+            if self.should_update_partition():
+                self.curPartitionId = (self.curPartitionId + 1) % self.partitionNumber
+                self.lastUpdatePartitionIdTime = Utils.current_time_mills()
+                self.lastAddMsgNumber = 0
+            currentPartitionId = self.curPartitionId
+            self.lastAddMsgNumber += len(msgList)
 
-        partitionBufferMap[currentPartitionId] = []
+            partitionBufferMap[currentPartitionId] = []
 
-        for message in msgList:
-            # set timestamp and messageType if not set;
-            Utils.update_message(message, MessageType.BINARY)
-            # check data validity
-            Utils.check_message_validity(message, self.talosProducerConfig)
+            for message in msgList:
+                # set timestamp and messageType if not set;
+                Utils.update_message(message, MessageType.BINARY)
+                # check data validity
+                Utils.check_message_validity(message, self.talosProducerConfig)
 
-            # check partitionKey setting and validity
-            if not message.partitionKey:
-            # straight forward put to cur partitionId queue
-                userMessage = UserMessage(message)
-                partitionBufferMap.get(currentPartitionId).append(userMessage)
-            else:
-                self.check_message_partition_key_validity(message.getPartitionKey())
-                # construct UserMessage and dispatch to buffer by partitionId
-                partitionId = self.get_partition_id(message.partitionKey)
-                if partitionId not in partitionBufferMap:
-                    partitionBufferMap[partitionId] = []
+                # check partitionKey setting and validity
+                if not message.partitionKey:
+                # straight forward put to cur partitionId queue
                     userMessage = UserMessage(message)
-                    partitionBufferMap.get(partitionId).append(userMessage)
+                    partitionBufferMap.get(currentPartitionId).append(userMessage)
+                else:
+                    self.check_message_partition_key_validity(message.getPartitionKey())
+                    # construct UserMessage and dispatch to buffer by partitionId
+                    partitionId = self.get_partition_id(message.partitionKey)
+                    if partitionId not in partitionBufferMap:
+                        partitionBufferMap[partitionId] = []
+                        userMessage = UserMessage(message)
+                        partitionBufferMap.get(partitionId).append(userMessage)
 
-        # add to partitionSender
-        for key, value in partitionBufferMap.items():
-            partitionId = key
-            assert partitionId in self.partitionSenderMap
-            self.partitionSenderMap.get(partitionId).add_message(value)
+            # add to partitionSender
+            for key, value in partitionBufferMap.items():
+                partitionId = key
+                assert partitionId in self.partitionSenderMap
+                self.partitionSenderMap.get(partitionId).add_message(value)
+        except Exception as e:
+            self.logger.error("do_add_user_message func error: " + traceback.format_exc())
+            raise e
 
     def should_update_partition(self):
         return (Utils.current_time_mills() - self.lastUpdatePartitionIdTime >=
@@ -237,7 +245,10 @@ class TalosProducer(object):
                                                     self.updatePartitionIdMsgNumber)
 
     def check_message_partition_key_validity(self, partitionKey=None):
-        assert not partitionKey
+        try:
+            assert not partitionKey
+        except AssertionError as e:
+            raise e
         if len(partitionKey) < self.partitionKeyMinLen or len(partitionKey) > self.partitionKeyMaxLen:
             raise InvalidArgumentError("Invalid partition key which length must be at "
                                        + "least " + str(self.partitionKeyMinLen) +
